

!!! Listing 1

    public String getImageName()
    {
        return imageName;
    }
    public void setImageName(String img)
    {
        if(imageName.equals(img)) {
            return;
        }

        imageName = img;
        setImage(null);

        if(img.equals("")) {
            return;
        }

        URL url = ResourcePool.getResourceURL(img);
        if(url != null) {
            setImage(Toolkit.getDefaultToolkit().getImage(url));
        }

        repaint();
    }

!! Listing 2

package resourcepool;

import java.net.URL;

/**
 *
 * This class implements a helper class for resource allocation
 *
 * @version  1.0
 * @author Uwe Steinmueller
 */

public class ResourcePool {

    static private ResourcePool singleton = new ResourcePool();

    /**
     * Creates an URL object from either an absolute URL as String or looks for
     * it relativly to class ResourcePool
     *
     * @param s absolute or relative URL as String
     */

    public static URL getResourceURL(String s) {
        try
        {
            URL url = null;
            try
            {
                url = new URL(s); // try as absolute URL
            }
            catch (Exception e) {
                url = null;
            }

            if(url == null) { // try as relative URL
                // url should not begin with '/'
                url = singleton.getClass().getResource(s);
            }
            return url;
        }

        catch (Exception ex) {
            return null;
        }
    }
}

!!! Listing 3


    public void setAllowResize(boolean b)
    {
        allowResize = b;
        repaint();
    }

    public boolean getAllowResize()
    {
        return allowResize;
    }

    public boolean getKeepAspectRatio()
    {
        return keepAspectRatio;
    }

    public void setKeepAspectRatio(boolean b)
    {
        keepAspectRatio = b;
        repaint();
    }

!!! Listing 4

package ustein.beans.diaview;

import java.beans.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;
import java.util.*;

public class DiaviewImageBeanInfo extends SimpleBeanInfo
{
    private final static Class beanClass = DiaviewImage.class;    

    private PropertyDescriptor makeBoundDesc(String name, String getter)
        throws IntrospectionException
    	PropertyDescriptor pd = new PropertyDescriptor(name, beanClass, "get" + getter,
 "set" + getter);
        pd.setBound(true);
        return pd;
    }

    public PropertyDescriptor[] getPropertyDescriptors()
    {
        try {
            PropertyDescriptor allowResize = makeBoundDesc("allowResize",  "AllowResize");
            PropertyDescriptor imageName = makeBoundDesc("imageURL",  "ImageName");
            PropertyDescriptor keepAspect = makeBoundDesc("keepAspectRatio",
                       "KeepAspectRatio");
            PropertyDescriptor back = makeBoundDesc("background", "Background");
            PropertyDescriptor name = makeBoundDesc("name", "Name");

            PropertyDescriptor rv[] = {imageName, allowResize, keepAspect, back, name};
            return rv;
        } catch (IntrospectionException e) {
            throw new Error(e.toString());
        }
    }

    public java.awt.Image getIcon(int iconKind) {
        if (iconKind == BeanInfo.ICON_MONO_16x16 ||
            iconKind == BeanInfo.ICON_COLOR_16x16 ) {
            java.awt.Image img = loadImage("DiaviewImage16.gif");
            return img;
        }
        if (iconKind == BeanInfo.ICON_MONO_32x32 ||
            iconKind == BeanInfo.ICON_COLOR_32x32 ) {
            java.awt.Image img = loadImage("DiaviewImage32.gif");
            return img;
        }
        return null;
    }
}

!!! Listing 5

    /* Serialization support.
     */

    private void writeObject(ObjectOutputStream s) throws IOException
    {
        s.defaultWriteObject();
    }

    private void readObject(ObjectInputStream is) throws ClassNotFoundException,
 IOException
    {
        is.defaultReadObject();
        // image is transient
        imgw = -1;
        imgh = -1;
        theImage = null;

        //cannot just call setImageName because setting the same name is a NOOP

        String img = getImageName();
        imageName = "";
        setImageName(img);
    }
